*================================================================================================;
*  Title:  PROGRAM P3: CALCULATES RISK-ADJUSTED PROVIDER
*          RATES FOR AHRQ INPATIENT QUALITY INDICATORS
*
*  Description:
*         USES MCMC TO CALCULATE RISK-ADJUSTED RATES FOR
*         INPATIENT QUALITY INDICATORS.
*         ADJUSTS FOR: SEX, AGE, APR-DRG SUBCLASS AND MDC
*
*          >>>  VERSION 4.5, MAY 2013 		 <<<
*
*  USER NOTE: Version 4.5 AHRQ QI SAS software does not explicitly support the calculation 
*             of weighted estimates and standard errors using complex sampling designs.
*             The variable DISCWT (discharge weight) is set equal to 1 in the SAS1 program  
*             for this module, and consequently the variable does not weight any calculations   
*             in this program.If a DISCWT variable is present in the users dataset, 
*             all values are set to 1. 
*
*             In order to obtain weighted nationally representative estimates, additional 
*             calculations will need to be performed.  
*             For a more thorough description of weighted AHRQ QI analyses beginning with 
*             AHRQ QI SAS Version 4.1, see the technical documentation on the AHRQ QI website.
*=================================================================================================;

FILENAME CONTROL 'c:\pathname\CONTROL_IQI.SAS';  *<===USER MUST modify;

%INCLUDE CONTROL;


TITLE2 'PROGRAM P3 PART I';
TITLE3 'AHRQ INPATIENT QUALITY INDICATORS: CALCULATE RISK-ADJUSTED PROVIDER RATES';

 * -------------------------------------------------------------- ;
 * --- INPATIENT QUALITY INDICATOR ADJUSTED RATES  -------------- ;
 * -------------------------------------------------------------- ;
 * --- THIS STEP SELECTS THE OBSERVATIONS FROM THE PROGRAM 1    - ;
 * --- OUTPUT FOR EACH INPATIENT QUALITY INDICATOR IN TURN.     - ;
 * --- EACH ITERATION PASSES VARIABLES THAT CONTROL THE         - ;
 * --- COVARIATES FOR THAT INPATIENT QUALITY INDICATOR:         - ;
 * --- N - OBSERVATION NUMBER FROM THE MEANS AND COVAR FILES    - ;
 * ---     ALSO IDENTIFIES THE FORMAT USED TO INDEX COVARIATES  - ;
 * --- IQ - THE INPATIENT QUALITY INDICATOR NAME WITHOUT THE    - ;
 * ---      PREFIX (P)                                          - ;
 * --- APRDRG - THE NAME OF THE VARIABLE CONTAINING APR-DRG     - ;
 * --- SUBCLS - THE NAME OF THE VARIABLE CONTAINING THE APR-    - ;
 * ---          DRG SUBCLASS APPROPRIATE FOR THAT INPATIENT     - ;
 * ---          QUALITY INDICATOR                               - ;
 * --- Z,X - NUMBER OF COVARIATES                               - ;
 * -------------------------------------------------------------- ;

 %MACRO ADDAPR;
    %IF &APRDRGFG EQ 1 %THEN &APRDRG &MORTAL &XMORTAL;
 %MEND;
 
 %MACRO MOD3(N,IQ,APRDRG,ZSUBCLS,XSUBCLS,Z,X);

 * --- THIS SET CREATES TEMP1 WHICH CONTAINS THE DEPENDENT      - ;
 * --- VARIABLE (TIQ) AND INDEPENDENT VARIABLES USED IN         - ;
 * --- REGRESSION.                                              - ;

 DATA TEMP1
   (KEEP=KEY HOSPID AGECAT SEXCAT PAYCAT RACECAT
         T&IQ. YT&IQ. P1 ZCV1-ZCV&Z. XCV1-XCV&X. DISCWT);
 LENGTH APRDRGZ APRDRGX $4 ZCV1-ZCV&Z. XCV1-XCV&X. P1 
        SIDX AIDX ZIDX XIDX MIDX 3;
 SET IN1.&INFILE1.
   (KEEP=KEY HOSPID
         POPCAT AGECAT SEXCAT PAYCAT RACECAT 
         T&IQ. %ADDAPR DISCWT
         NOPOA TRNSFER NOPOUB04 RUPTURED MDC);

 * --- KEEP ONLY DISCHARGES NEEDED FOR THIS IQ ------------------ ;
 IF T&IQ. NE .;

 * --- INITIALIZE COVARIATE DUMMIES TO ZERO --------------------- ;
 ARRAY ZCV{&Z.} ZCV1-ZCV&Z.;
 ARRAY XCV{&X.} XCV1-XCV&X.;

 DO I = 1 TO &Z.;
   ZCV(I) = 0;
 END;

 DO I = 1 TO &X.;
   XCV(I) = .;
   IF NOPOA IN (0) THEN XCV(I) = 0; 
 END;

 * --- SET INDEX FOR SEX, AGE, APRDRG AND MDC                 --- ;
 * --- CATEGORIES VARY BY INPATIENT QUALITY INDICATOR AND ARE --- ;
 * --- DETERMINED BY THE FORMAT CORRESPONDING TO N.           --- ;

 SIDX = PUT(SEXCAT,S&N.IQFMT.);
 AIDX = PUT(POPCAT,A&N.IQFMT.);

 IF &ZSUBCLS. >= 0 THEN DO;
    APRDRGZ = PUT(&APRDRG.,Z3.)||PUT(&ZSUBCLS.,Z1.);
    ZIDX = PUT(APRDRGZ,$C&N.IQFM.);
 END;
 ELSE ZIDX = 0;

 IF &XSUBCLS. >= 0 THEN DO;
    APRDRGX = PUT(&APRDRG.,Z3.)||PUT(&XSUBCLS.,Z1.);
    XIDX = PUT(APRDRGX,$C&N.IQFM.);
 END; 
 ELSE XIDX = 0;
 
 MIDX = PUT(MDC,M&N.IQFMT.);

 * --- SET APPROPRIATE COVARIATE DUMMY TO 1 FOR THIS DISCHARGE  - ;
 IF SIDX > 0 THEN ZCV(SIDX) = 1; 
 IF AIDX > 0 THEN ZCV(AIDX) = 1; 
 IF ZIDX > 0 THEN ZCV(ZIDX) = 1;
 IF ZIDX = -1 AND MIDX > 0 THEN ZCV(MIDX) = 1;

 IF NOPOA IN (0) THEN DO;
    IF SIDX > 0 THEN XCV(SIDX) = 1; 
    IF AIDX > 0 THEN XCV(AIDX) = 1; 
    IF XIDX > 0 THEN XCV(XIDX) = 1; 
    IF XIDX = -1 AND MIDX > 0 THEN XCV(MIDX) = 1;
 END;

 IF &N. = 11  THEN DO;
    IF RUPTURED THEN ZCV(11) = 1;
 END;

 IF &N. = 13 THEN DO;
    IF TRNSFER THEN ZCV(16) = 1;
 END;

 IF &N. = 15 THEN DO;
    IF TRNSFER THEN ZCV(26) = 1;
 END;

 IF &N. = 16 THEN DO;
    IF TRNSFER THEN ZCV(27) = 1;
    IF NOPOUB04 THEN ZCV(28) = 1;
 END;

 IF &N. = 17  THEN DO;
    IF NOPOUB04 THEN ZCV(29) = 1;
 END;
 
 IF &N. = 18 THEN DO;
    IF TRNSFER THEN ZCV(24) = 1;
 END;

 IF &N. = 19 THEN DO;
    IF TRNSFER THEN ZCV(16) = 1;
    IF NOPOUB04 THEN ZCV(17) = 1;
 END;

 IF &N. = 20 THEN DO;
    IF TRNSFER THEN ZCV(28) = 1;
 END;

 IF &N. = 30 THEN DO;
    IF TRNSFER THEN ZCV(20) = 1;
    IF NOPOUB04 THEN ZCV(21) = 1;
 END;

 IF NOPOA IN (0) THEN DO;
    IF &N. = 11 THEN DO;
       IF RUPTURED THEN XCV(11) = 1;
    END;
    IF &N. = 13 THEN DO;
       IF TRNSFER THEN XCV(16) = 1;
    END;
    IF &N. = 15 THEN DO;
       IF TRNSFER THEN XCV(26) = 1;
    END;
    IF &N. = 16 THEN DO;
       IF TRNSFER THEN XCV(27) = 1;
       IF NOPOUB04 THEN XCV(28) = 1;
    END;
    IF &N. = 17 THEN DO;
       IF NOPOUB04 THEN XCV(29) = 1;
    END;
    IF &N. = 18 THEN DO;
       IF TRNSFER THEN XCV(24) = 1;
    END;
    IF &N. = 19 THEN DO;
       IF TRNSFER THEN XCV(16) = 1;
       IF NOPOUB04 THEN XCV(17) = 1;
    END;
    IF &N. = 20 THEN DO;
       IF TRNSFER THEN XCV(28) = 1;
    END;
    IF &N. = 30 THEN DO;
       IF TRNSFER THEN XCV(20) = 1;
       IF NOPOUB04 THEN XCV(21) = 1;
    END;
 END;

 YT&IQ. = T&IQ.;
 *P1 = QPIQ&IQ.;
 P1 = .;
 IF NOPOA IN (0) THEN P1 = 0;
 RUN;

 %let dsid=%sysfunc(open(temp1));
 %let dnum=%sysfunc(attrn(&dsid,nobs));
 %let drc=%sysfunc(close(&dsid));

 %if &dnum ne 0 %then %do;

 DATA TEMP1Y;
 LENGTH KEY HOSPID 8 YT&IQ. P1 ZCV1-ZCV&Z. XCV1-XCV&X. 3;
 SET TEMP1
   (KEEP=KEY HOSPID
         YT&IQ. P1 
         ZCV1-ZCV&Z. XCV1-XCV&X.);

  RUN;

 PROC SORT DATA=TEMP1Y;
 BY HOSPID KEY;
 RUN;

 PROC MEANS DATA=TEMP1Y N MEAN;
 VAR YT&IQ. P1 ZCV1-ZCV&Z. XCV1-XCV&X.;
 RUN;

 DATA TEMP1W;
 SET TEMP1
   (KEEP=KEY HOSPID 
         AGECAT SEXCAT PAYCAT RACECAT
         T&IQ. DISCWT);

 RUN;

 PROC SORT DATA=TEMP1W;
 BY HOSPID KEY;
 RUN;

 %INCLUDE PRDP;

 PROC SORT DATA=TEMP1I(KEEP=HOSPID KEY P P_Y_P_X_Z  Y_Z Y_P_0 Y_X_P_0_MCMC );
 BY HOSPID KEY;
 RUN;

 DATA TEMP1W;
 MERGE TEMP1W TEMP1I;
 BY HOSPID KEY;

 %INCLUDE MSXP;

 IF &N. =  8 AND "&IQ." = "PIQ08"  THEN SUB_N = 1;

 IF &N. =  9 AND "&IQ." = "PIQ09"  THEN SUB_N = 2;
 IF &N. =  9 AND "&IQ." = "PIQ09A" THEN SUB_N = 3;
 IF &N. =  9 AND "&IQ." = "PIQ09B" THEN SUB_N = 4;

 IF &N. = 11 AND "&IQ." = "PIQ11"  THEN SUB_N = 5;
 IF &N. = 11 AND "&IQ." = "PIQ11A" THEN SUB_N = 6;
 IF &N. = 11 AND "&IQ." = "PIQ11B" THEN SUB_N = 7;
 IF &N. = 11 AND "&IQ." = "PIQ11C" THEN SUB_N = 8;
 IF &N. = 11 AND "&IQ." = "PIQ11D" THEN SUB_N = 9;

 IF &N. = 12 AND "&IQ." = "PIQ12"  THEN SUB_N = 10;
 IF &N. = 13 AND "&IQ." = "PIQ13"  THEN SUB_N = 11;
 IF &N. = 14 AND "&IQ." = "PIQ14"  THEN SUB_N = 12;
 IF &N. = 15 AND "&IQ." = "PIQ15"  THEN SUB_N = 13;
 IF &N. = 16 AND "&IQ." = "PIQ16"  THEN SUB_N = 14;

 IF &N. = 17 AND "&IQ." = "PIQ17"  THEN SUB_N = 15;
 IF &N. = 17 AND "&IQ." = "PIQ17A" THEN SUB_N = 16;
 IF &N. = 17 AND "&IQ." = "PIQ17B" THEN SUB_N = 17;
 IF &N. = 17 AND "&IQ." = "PIQ17C" THEN SUB_N = 18;

 IF &N. = 18 AND "&IQ." = "PIQ18"  THEN SUB_N = 19;
 IF &N. = 19 AND "&IQ." = "PIQ19"  THEN SUB_N = 20;
 IF &N. = 20 AND "&IQ." = "PIQ20"  THEN SUB_N = 21;

 IF &N. = 30 AND "&IQ." = "PIQ30"  THEN SUB_N = 27;
 IF &N. = 31 AND "&IQ." = "PIQ31"  THEN SUB_N = 28;
 IF &N. = 32 AND "&IQ." = "PIQ32"  THEN SUB_N = 29;


 IF &USEPOA. = 0 THEN DO;
 EHAT = (ARRYP6(SUB_N)/(ARRYP6(SUB_N)-ARRYP7(SUB_N))) * Y_Z;
 END;
 ELSE DO;
 EHAT = (ARRYP3(SUB_N)/(ARRYP3(SUB_N)-ARRYP4(SUB_N))) * Y_X_P_0_MCMC;
 END;
 PHAT = EHAT * (1 - EHAT);
 
 IF &USEPOA. = 0 THEN DO;
 PWHT = DISCWT;
 END;
 ELSE DO;
 T&IQ. = Y_P_0;
 IF P = . THEN PWHT = (1 - P_Y_P_X_Z) * DISCWT; 
 ELSE PWHT = (1 - P) * DISCWT;
 END;

 RUN;

 PROC SUMMARY DATA=TEMP1W;
 CLASS HOSPID AGECAT SEXCAT PAYCAT RACECAT;
 VAR T&IQ. EHAT PWHT PHAT;
 OUTPUT OUT=R&IQ. SUM(T&IQ. EHAT PWHT PHAT)=T&IQ. EHAT P&IQ PHAT 
                  ;
 RUN;

 DATA R&IQ.(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT _TYPE_
                 E&IQ. R&IQ. L&IQ. U&IQ. S&IQ. X&IQ. V&IQ.
                 T&IQ. P&IQ. O&IQ.);
 SET R&IQ.;

 IF _TYPE_ &TYPELVLP;

 %INCLUDE MSXP;

 IF &N. =  8 AND "&IQ." = "PIQ08"  THEN SUB_N = 1;

 IF &N. =  9 AND "&IQ." = "PIQ09"  THEN SUB_N = 2;
 IF &N. =  9 AND "&IQ." = "PIQ09A" THEN SUB_N = 3;
 IF &N. =  9 AND "&IQ." = "PIQ09B" THEN SUB_N = 4;

 IF &N. = 11 AND "&IQ." = "PIQ11"  THEN SUB_N = 5;
 IF &N. = 11 AND "&IQ." = "PIQ11A" THEN SUB_N = 6;
 IF &N. = 11 AND "&IQ." = "PIQ11B" THEN SUB_N = 7;
 IF &N. = 11 AND "&IQ." = "PIQ11C" THEN SUB_N = 8;
 IF &N. = 11 AND "&IQ." = "PIQ11D" THEN SUB_N = 9;

 IF &N. = 12 AND "&IQ." = "PIQ12"  THEN SUB_N = 10;
 IF &N. = 13 AND "&IQ." = "PIQ13"  THEN SUB_N = 11;
 IF &N. = 14 AND "&IQ." = "PIQ14"  THEN SUB_N = 12;
 IF &N. = 15 AND "&IQ." = "PIQ15"  THEN SUB_N = 13;
 IF &N. = 16 AND "&IQ." = "PIQ16"  THEN SUB_N = 14;

 IF &N. = 17 AND "&IQ." = "PIQ17"  THEN SUB_N = 15;
 IF &N. = 17 AND "&IQ." = "PIQ17A" THEN SUB_N = 16;
 IF &N. = 17 AND "&IQ." = "PIQ17B" THEN SUB_N = 17;
 IF &N. = 17 AND "&IQ." = "PIQ17C" THEN SUB_N = 18;

 IF &N. = 18 AND "&IQ." = "PIQ18"  THEN SUB_N = 19;
 IF &N. = 19 AND "&IQ." = "PIQ19"  THEN SUB_N = 20;
 IF &N. = 20 AND "&IQ." = "PIQ20"  THEN SUB_N = 21;
 IF &N. = 30 AND "&IQ." = "PIQ30"  THEN SUB_N = 27;
 IF &N. = 31 AND "&IQ." = "PIQ31"  THEN SUB_N = 28;
 IF &N. = 32 AND "&IQ." = "PIQ32"  THEN SUB_N = 29;

 T&IQ. = ROUND(T&IQ.,1);
 P&IQ. = ROUND(P&IQ.,1);

 E&IQ. = EHAT / P&IQ.;
 O&IQ. = T&IQ. / P&IQ.;
 
 IF PHAT < 0 THEN DO;
    R&IQ.   = .;
    SE&IQ.  = .;
    V&IQ.   = .;
    S&IQ.   = .;
    X&IQ.   = .;
 END;
 ELSE IF _TYPE_ IN (0,16) THEN DO;
 IF &USEPOA. = 0 THEN DO;
    R&IQ.   = (O&IQ. / E&IQ.) * ARRYP6(SUB_N);
    SE&IQ.  = (ARRYP6(SUB_N) / E&IQ.) * (1 / P&IQ.) * SQRT(PHAT);
    V&IQ.   = SE&IQ.**2;
    SN&IQ.  = ARRYP5(SUB_N) / (ARRYP5(SUB_N) + V&IQ.);
    S&IQ.   = (R&IQ. * SN&IQ.) + ((1 -  SN&IQ.) * ARRYP6(SUB_N));
    X&IQ.   = SQRT(ARRYP5(SUB_N)- (SN&IQ. * ARRYP5(SUB_N)));
 END;
 ELSE DO;
    R&IQ.   = (O&IQ. / E&IQ.) * ARRYP3(SUB_N);
    SE&IQ.  = (ARRYP3(SUB_N) / E&IQ.) * (1 / P&IQ.) * SQRT(PHAT);
    V&IQ.   = SE&IQ.**2;
    SN&IQ.  = ARRYP2(SUB_N) / (ARRYP2(SUB_N) + V&IQ.);
    S&IQ.   = (R&IQ. * SN&IQ.) + ((1 -  SN&IQ.) * ARRYP3(SUB_N));
    X&IQ.   = SQRT(ARRYP2(SUB_N)- (SN&IQ. * ARRYP2(SUB_N)));
 END;
 END;
 ELSE DO;
    R&IQ.   = (O&IQ./ E&IQ.);
    SE&IQ.  = (1 / E&IQ.) * (1 / P&IQ.) * SQRT(PHAT);
    V&IQ.   = .;
    S&IQ.   = .;
    X&IQ.   = .;
 END;

 L&IQ.   = R&IQ. - (1.96 * SE&IQ.);
 IF L&IQ. < 0 THEN L&IQ. = 0;
 U&IQ.   = R&IQ. + (1.96 * SE&IQ.);


 IF _TYPE_ IN (0,16) THEN DO;
     IF L&IQ. > 1 THEN L&IQ. = 1;
	 IF U&IQ. > 1 THEN U&IQ. = 1;
	 IF R&IQ. > 1 THEN R&IQ. = 1;
 END;

 RUN;

 %end;
 %else %do;

 DATA   R&IQ.;
    HOSPID=.;AGECAT=.;SEXCAT=.;PAYCAT=.;RACECAT=.;_TYPE_=0;
    E&IQ=.;R&IQ=.;L&IQ=.;U&IQ=.;S&IQ=.;X&IQ=.;V&IQ =.;
    T&IQ =.;P&IQ=.;O&IQ =.;
    OUTPUT;
 RUN;

 %end;
                  
 DATA R&IQ.;
   SET R&IQ.;
   IF "&IQ." IN ("PIQ09A", "PIQ09B", "PIQ11A" , "PIQ11B", "PIQ11C", "PIQ11D", 
                "PIQ17A", "PIQ17B", "PIQ17C")  THEN DO;
      S&IQ. = .;
      X&IQ. = .;
   END;
 RUN; 

 PROC SORT DATA=R&IQ.;
   BY HOSPID AGECAT SEXCAT PAYCAT RACECAT;
 RUN; QUIT;
   
 PROC   DATASETS NOLIST;
 DELETE TEMP1 TEMP1Y TEMP1W;
 RUN;

 %MEND;

 %MOD3(8,PIQ08,&APRDRG.,&MORTAL.,&XMORTAL.,5,5);

 %MOD3(9,PIQ09, &APRDRG.,&MORTAL.,&XMORTAL.,6,6);
 %MOD3(9,PIQ09A,&APRDRG.,&MORTAL.,&XMORTAL.,6,6);
 %MOD3(9,PIQ09B,&APRDRG.,&MORTAL.,&XMORTAL.,6,6);

 %MOD3(11,PIQ11, &APRDRG.,&MORTAL.,&XMORTAL.,11,11);
 %MOD3(11,PIQ11A,&APRDRG.,&MORTAL.,&XMORTAL.,11,11);
 %MOD3(11,PIQ11B,&APRDRG.,&MORTAL.,&XMORTAL.,11,11);
 %MOD3(11,PIQ11C,&APRDRG.,&MORTAL.,&XMORTAL.,11,11);
 %MOD3(11,PIQ11D,&APRDRG.,&MORTAL.,&XMORTAL.,11,11);

 %MOD3(12,PIQ12,&APRDRG.,&MORTAL.,&XMORTAL.,23,23);
 %MOD3(13,PIQ13,&APRDRG.,&MORTAL.,&XMORTAL.,16,16);
 %MOD3(14,PIQ14,&APRDRG.,&MORTAL.,&XMORTAL.,6,6);
 %MOD3(15,PIQ15,&APRDRG.,&MORTAL.,&XMORTAL.,26,26);
 %MOD3(16,PIQ16,&APRDRG.,&MORTAL.,&XMORTAL.,28,28);

 %MOD3(17,PIQ17, &APRDRG.,&MORTAL.,&XMORTAL.,29,29);
 %MOD3(17,PIQ17A,&APRDRG.,&MORTAL.,&XMORTAL.,29,29);
 %MOD3(17,PIQ17B,&APRDRG.,&MORTAL.,&XMORTAL.,29,29);
 %MOD3(17,PIQ17C,&APRDRG.,&MORTAL.,&XMORTAL.,29,29);

 %MOD3(18,PIQ18,&APRDRG.,&MORTAL.,&XMORTAL.,24,24);
 %MOD3(19,PIQ19,&APRDRG.,&MORTAL.,&XMORTAL.,17,17);
 %MOD3(20,PIQ20,&APRDRG.,&MORTAL.,&XMORTAL.,28,28);
 %MOD3(30,PIQ30,&APRDRG.,&MORTAL.,&XMORTAL.,21,21);
 %MOD3(31,PIQ31,&APRDRG.,&MORTAL.,&XMORTAL.,6,6);
 %MOD3(32,PIQ32,&APRDRG.,&MORTAL.,&XMORTAL.,23,23);


 * --- MERGES THE AREA ADJUSTED RATES FOR EACH INPATIENT QUALITY  - ;
 * --- INDICATOR.  PREFIX FOR THE ADJUSTED RATES IS (R).          - ;

 DATA   RISKADJ;
 MERGE  RPIQ08 (KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ08 RPIQ08 LPIQ08 UPIQ08 SPIQ08 XPIQ08 VPIQ08 TPIQ08 PPIQ08 OPIQ08)

        RPIQ09 (KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ09  RPIQ09  LPIQ09  UPIQ09  SPIQ09  XPIQ09  VPIQ09  TPIQ09  PPIQ09  OPIQ09)
        RPIQ09A(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ09A RPIQ09A LPIQ09A UPIQ09A SPIQ09A XPIQ09A VPIQ09A TPIQ09A PPIQ09A OPIQ09A)
        RPIQ09B(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ09B RPIQ09B LPIQ09B UPIQ09B SPIQ09B XPIQ09B VPIQ09B TPIQ09B PPIQ09B OPIQ09B)

        RPIQ11 (KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ11  RPIQ11  LPIQ11  UPIQ11  SPIQ11  XPIQ11  VPIQ11  TPIQ11  PPIQ11  OPIQ11) 
        RPIQ11A(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ11A RPIQ11A LPIQ11A UPIQ11A SPIQ11A XPIQ11A VPIQ11A TPIQ11A PPIQ11A OPIQ11A)
        RPIQ11B(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ11B RPIQ11B LPIQ11B UPIQ11B SPIQ11B XPIQ11B VPIQ11B TPIQ11B PPIQ11B OPIQ11B)
        RPIQ11C(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ11C RPIQ11C LPIQ11C UPIQ11C SPIQ11C XPIQ11C VPIQ11C TPIQ11C PPIQ11C OPIQ11C)
        RPIQ11D(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ11D RPIQ11D LPIQ11D UPIQ11D SPIQ11D XPIQ11D VPIQ11D TPIQ11D PPIQ11D OPIQ11D)

        RPIQ12(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ12 RPIQ12 LPIQ12 UPIQ12 SPIQ12 XPIQ12 VPIQ12 TPIQ12 PPIQ12 OPIQ12)
        RPIQ13(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ13 RPIQ13 LPIQ13 UPIQ13 SPIQ13 XPIQ13 VPIQ13 TPIQ13 PPIQ13 OPIQ13)
        RPIQ14(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ14 RPIQ14 LPIQ14 UPIQ14 SPIQ14 XPIQ14 VPIQ14 TPIQ14 PPIQ14 OPIQ14)
        RPIQ15(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ15 RPIQ15 LPIQ15 UPIQ15 SPIQ15 XPIQ15 VPIQ15 TPIQ15 PPIQ15 OPIQ15)
        RPIQ16(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ16 RPIQ16 LPIQ16 UPIQ16 SPIQ16 XPIQ16 VPIQ16 TPIQ16 PPIQ16 OPIQ16)

        RPIQ17 (KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ17  RPIQ17  LPIQ17  UPIQ17  SPIQ17  XPIQ17  VPIQ17  TPIQ17  PPIQ17  OPIQ17)
        RPIQ17A(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ17A RPIQ17A LPIQ17A UPIQ17A SPIQ17A XPIQ17A VPIQ17A TPIQ17A PPIQ17A OPIQ17A)
        RPIQ17B(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ17B RPIQ17B LPIQ17B UPIQ17B SPIQ17B XPIQ17B VPIQ17B TPIQ17B PPIQ17B OPIQ17B)
        RPIQ17C(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ17C RPIQ17C LPIQ17C UPIQ17C SPIQ17C XPIQ17C VPIQ17C TPIQ17C PPIQ17C OPIQ17C)

        RPIQ18(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ18 RPIQ18 LPIQ18 UPIQ18 SPIQ18 XPIQ18 VPIQ18 TPIQ18 PPIQ18 OPIQ18)
        RPIQ19(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ19 RPIQ19 LPIQ19 UPIQ19 SPIQ19 XPIQ19 VPIQ19 TPIQ19 PPIQ19 OPIQ19)
        RPIQ20(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ20 RPIQ20 LPIQ20 UPIQ20 SPIQ20 XPIQ20 VPIQ20 TPIQ20 PPIQ20 OPIQ20)
        RPIQ30(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ30 RPIQ30 LPIQ30 UPIQ30 SPIQ30 XPIQ30 VPIQ30 TPIQ30 PPIQ30 OPIQ30)
        RPIQ31(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ31 RPIQ31 LPIQ31 UPIQ31 SPIQ31 XPIQ31 VPIQ31 TPIQ31 PPIQ31 OPIQ31)
        RPIQ32(KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT EPIQ32 RPIQ32 LPIQ32 UPIQ32 SPIQ32 XPIQ32 VPIQ32 TPIQ32 PPIQ32 OPIQ32);

 BY HOSPID AGECAT SEXCAT PAYCAT RACECAT;

 LABEL
 PPIQ08 = 'IQI #8 Esophageal Resection Mortality Rate (Population)'
 PPIQ09 = 'IQI #9 Pancreatic Resection Mortality Rate (Population)'
 PPIQ09A = 'IQI #9 Pancreatic Resection Mortality Rate Stratum A (Population)'
 PPIQ09B = 'IQI #9 Pancreatic Resection Mortality Rate Stratum B (Population)'
 PPIQ11 = 'IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate (Population)'
 PPIQ11A = 'IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum A (Population)'
 PPIQ11B = 'IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum B (Population)'
 PPIQ11C = 'IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum C (Population)'
 PPIQ11D = 'IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum D (Population)'
 PPIQ12 = 'IQI #12 Coronary Artery Bypass Graft (CABG) Mortality Rate (Population)'
 PPIQ13 = 'IQI #13 Craniotomy Mortality Rate (Population)'
 PPIQ14 = 'IQI #14 Hip Replacement Mortality Rate (Population)'
 PPIQ15 = 'IQI #15 Acute Myocardial Infarction (AMI) Mortality Rate (Population)'
 PPIQ16 = 'IQI #16 Heart Failure Mortality Rate (Population)'
 PPIQ17 = 'IQI #17 Acute Stroke Mortality Rate (Population)'
 PPIQ17A = 'IQI #17 Acute Stroke Mortality Rate Stratum A (Population)'
 PPIQ17B = 'IQI #17 Acute Stroke Mortality Rate Stratum B (Population)'
 PPIQ17C = 'IQI #17 Acute Stroke Mortality Rate Stratum C (Population)'
 PPIQ18 = 'IQI #18 Gastrointestinal Hemorrhage Mortality Rate (Population)'
 PPIQ19 = 'IQI #19 Hip Fracture Mortality Rate (Population)'
 PPIQ20 = 'IQI #20 Pneumonia Mortality Rate (Population)'
 PPIQ30 = 'IQI #30 Percutaneous Coronary Intervention (PCI) Mortality Rate (Population)'
 PPIQ31 = 'IQI #31 Carotid Endarterectomy Mortality Rate (Population)'
 PPIQ32 = 'IQI #32 Acute Myocardial Infarction (AMI) Mortality Rate, Without Transfer Cases (Population)'
 ;

 LABEL
 OPIQ08 = 'IQI #8 Esophageal Resection Mortality Rate (Observed)'
 OPIQ09 = 'IQI #9 Pancreatic Resection Mortality Rate (Observed)'
 OPIQ09A = 'IQI #9 Pancreatic Resection Mortality Rate Stratum A (Observed)'
 OPIQ09B = 'IQI #9 Pancreatic Resection Mortality Rate Stratum B (Observed)'
 OPIQ11 = 'IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate (Observed)'
 OPIQ11A = 'IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum A (Observed)'
 OPIQ11B = 'IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum B (Observed)'
 OPIQ11C = 'IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum C (Observed)'
 OPIQ11D = 'IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum D (Observed)'
 OPIQ12 = 'IQI #12 Coronary Artery Bypass Graft (CABG) Mortality Rate (Observed)'
 OPIQ13 = 'IQI #13 Craniotomy Mortality Rate (Observed)'
 OPIQ14 = 'IQI #14 Hip Replacement Mortality Rate (Observed)'
 OPIQ15 = 'IQI #15 Acute Myocardial Infarction (AMI) Mortality Rate (Observed)'
 OPIQ16 = 'IQI #16 Heart Failure Mortality Rate (Observed)'
 OPIQ17 = 'IQI #17 Acute Stroke Mortality Rate (Observed)'
 OPIQ17A = 'IQI #17 Acute Stroke Mortality Rate Stratum A (Observed)'
 OPIQ17B = 'IQI #17 Acute Stroke Mortality Rate Stratum B (Observed)'
 OPIQ17C = 'IQI #17 Acute Stroke Mortality Rate Stratum C (Observed)'
 OPIQ18 = 'IQI #18 Gastrointestinal Hemorrhage Mortality Rate (Observed)'
 OPIQ19 = 'IQI #19 Hip Fracture Mortality Rate (Observed)'
 OPIQ20 = 'IQI #20 Pneumonia Mortality Rate (Observed)'
 OPIQ30 = 'IQI #30 Percutaneous Coronary Intervention (PCI) Mortality Rate (Observed)'
 OPIQ31 = 'IQI #31 Carotid Endarterectomy Mortality Rate (Observed)'
 OPIQ32 = 'IQI #32 Acute Myocardial Infarction (AMI) Mortality Rate, Without Transfer Cases (Observed)'
 ;

 LABEL
 EPIQ08  ='IQI #8 Esophageal Resection Mortality Rate (Expected)'
 EPIQ09  ='IQI #9 Pancreatic Resection Mortality Rate (Expected)'
 EPIQ09A ='IQI #9 Pancreatic Resection Mortality Rate Stratum A (Expected)'
 EPIQ09B ='IQI #9 Pancreatic Resection Mortality Rate Stratum B (Expected)'
 EPIQ11  ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate (Expected)'
 EPIQ11A ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum A (Expected)'
 EPIQ11B ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum B (Expected)'
 EPIQ11C ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum C (Expected)'
 EPIQ11D ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum D (Expected)'
 EPIQ12 ='IQI #12 Coronary Artery Bypass Graft (CABG) Mortality Rate (Expected)'
 EPIQ13 ='IQI #13 Craniotomy Mortality Rate (Expected)'
 EPIQ14 ='IQI #14 Hip Replacement Mortality Rate (Expected)'
 EPIQ15 ='IQI #15 Acute Myocardial Infarction (AMI) Mortality Rate (Expected)'
 EPIQ16 ='IQI #16 Heart Failure Mortality Rate (Expected)'
 EPIQ17  ='IQI #17 Acute Stroke Mortality Rate (Expected)'
 EPIQ17A ='IQI #17 Acute Stroke Mortality Rate Stratum A (Expected)'
 EPIQ17B ='IQI #17 Acute Stroke Mortality Rate Stratum B (Expected)'
 EPIQ17C ='IQI #17 Acute Stroke Mortality Rate Stratum C (Expected)'
 EPIQ18 ='IQI #18 Gastrointestinal Hemorrhage Mortality Rate (Expected)'
 EPIQ19 ='IQI #19 Hip Fracture Mortality Rate (Expected)'
 EPIQ20 ='IQI #20 Pneumonia Mortality Rate (Expected)'
 EPIQ30 ='IQI #30 Percutaneous Coronary Intervention (PCI) Mortality Rate (Expected)'
 EPIQ31 ='IQI #31 Carotid Endarterectomy Mortality Rate (Expected)'
 EPIQ32 ='IQI #32 Acute Myocardial Infarction (AMI) Mortality Rate, Without Transfer Cases (Expected)'
 ;

 LABEL
 RPIQ08 ='IQI #8 Esophageal Resection Mortality Rate (Risk Adj)'
 RPIQ09  ='IQI #9 Pancreatic Resection Mortality Rate (Risk Adj)'
 RPIQ09A ='IQI #9 Pancreatic Resection Mortality Rate Stratum A (Risk Adj)'
 RPIQ09B ='IQI #9 Pancreatic Resection Mortality Rate Stratum B (Risk Adj)'
 RPIQ11  ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate (Risk Adj)'
 RPIQ11A ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum A (Risk Adj)'
 RPIQ11B ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum B (Risk Adj)'
 RPIQ11C ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum C (Risk Adj)'
 RPIQ11D ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum D (Risk Adj)'
 RPIQ12 ='IQI #12 Coronary Artery Bypass Graft (CABG) Mortality Rate (Risk Adj)'
 RPIQ13 ='IQI #13 Craniotomy Mortality Rate (Risk Adj)'
 RPIQ14 ='IQI #14 Hip Replacement Mortality Rate (Risk Adj)'
 RPIQ15 ='IQI #15 Acute Myocardial Infarction (AMI) Mortality Rate (Risk Adj)'
 RPIQ16 ='IQI #16 Heart Failure Mortality Rate (Risk Adj)'
 RPIQ17  ='IQI #17 Acute Stroke Mortality Rate (Risk Adj)'
 RPIQ17A ='IQI #17 Acute Stroke Mortality Rate Stratum A (Risk Adj)'
 RPIQ17B ='IQI #17 Acute Stroke Mortality Rate Stratum B (Risk Adj)'
 RPIQ17C ='IQI #17 Acute Stroke Mortality Rate Stratum C (Risk Adj)'
 RPIQ18 ='IQI #18 Gastrointestinal Hemorrhage Mortality Rate (Risk Adj)'
 RPIQ19 ='IQI #19 Hip Fracture Mortality Rate (Risk Adj)'
 RPIQ20 ='IQI #20 Pneumonia Mortality Rate (Risk Adj)'
 RPIQ30 ='IQI #30 Percutaneous Coronary Intervention (PCI) Mortality Rate (Risk Adj)'
 RPIQ31 ='IQI #31 Carotid Endarterectomy Mortality Rate (Risk Adj)'
 RPIQ32 ='IQI #32 Acute Myocardial Infarction (AMI) Mortality Rate, Without Transfer Cases (Risk Adj)'
 ;

 LABEL
 LPIQ08 ='IQI #8 Esophageal Resection Mortality Rate (Lower CL)'
 LPIQ09  ='IQI #9 Pancreatic Resection Mortality Rate (Lower CL)'
 LPIQ09A ='IQI #9 Pancreatic Resection Mortality Rate Stratum A (Lower CL)'
 LPIQ09B ='IQI #9 Pancreatic Resection Mortality Rate Stratum B (Lower CL)'
 LPIQ11  ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate (Lower CL)'
 LPIQ11A ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum A (Lower CL)'
 LPIQ11B ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum B (Lower CL)'
 LPIQ11C ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum C (Lower CL)'
 LPIQ11D ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum D (Lower CL)'
 LPIQ12 ='IQI #12 Coronary Artery Bypass Graft (CABG) Mortality Rate (Lower CL)'
 LPIQ13 ='IQI #13 Craniotomy Mortality Rate (Lower CL)'
 LPIQ14 ='IQI #14 Hip Replacement Mortality Rate (Lower CL)'
 LPIQ15 ='IQI #15 Acute Myocardial Infarction (AMI) Mortality Rate (Lower CL)'
 LPIQ16 ='IQI #16 Heart Failure Mortality Rate (Lower CL)'
 LPIQ17  ='IQI #17 Acute Stroke Mortality Rate (Lower CL)'
 LPIQ17A ='IQI #17 Acute Stroke Mortality Rate Stratum A (Lower CL)'
 LPIQ17B ='IQI #17 Acute Stroke Mortality Rate Stratum B (Lower CL)'
 LPIQ17C ='IQI #17 Acute Stroke Mortality Rate Stratum C (Lower CL)'
 LPIQ18 ='IQI #18 Gastrointestinal Hemorrhage Mortality Rate (Lower CL)'
 LPIQ19 ='IQI #19 Hip Fracture Mortality Rate (Lower CL)'
 LPIQ20 ='IQI #20 Pneumonia Mortality Rate (Lower CL)'
 LPIQ30 ='IQI #30 Percutaneous Coronary Intervention (PCI) Mortality Rate (Lower CL)'
 LPIQ31 ='IQI #31 Carotid Endarterectomy Mortality Rate (Lower CL)'
 LPIQ32 ='IQI #32 Acute Myocardial Infarction (AMI) Mortality Rate, Without Transfer Cases (Lower CL)'
 ;

 LABEL
 UPIQ08 ='IQI #8 Esophageal Resection Mortality Rate (Upper CL)'
 UPIQ09  ='IQI #9 Pancreatic Resection Mortality Rate (Upper CL)'
 UPIQ09A ='IQI #9 Pancreatic Resection Mortality Rate Stratum A (Upper CL)'
 UPIQ09B ='IQI #9 Pancreatic Resection Mortality Rate Stratum A (Upper CL)'
 UPIQ11  ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate (Upper CL)'
 UPIQ11A ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum A (Upper CL)'
 UPIQ11B ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum B (Upper CL)'
 UPIQ11C ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum C (Upper CL)'
 UPIQ11D ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum D (Upper CL)'
 UPIQ12 ='IQI #12 Coronary Artery Bypass Graft (CABG) Mortality Rate (Upper CL)'
 UPIQ13 ='IQI #13 Craniotomy Mortality Rate (Upper CL)'
 UPIQ14 ='IQI #14 Hip Replacement Mortality Rate (Upper CL)'
 UPIQ15 ='IQI #15 Acute Myocardial Infarction (AMI) Mortality Rate (Upper CL)'
 UPIQ16 ='IQI #16 Heart Failure Mortality Rate (Upper CL)'
 UPIQ17  ='IQI #17 Acute Stroke Mortality Rate (Upper CL)'
 UPIQ17A ='IQI #17 Acute Stroke Mortality Rate Stratum A (Upper CL)'
 UPIQ17B ='IQI #17 Acute Stroke Mortality Rate Stratum B (Upper CL)'
 UPIQ17C ='IQI #17 Acute Stroke Mortality Rate Stratum C (Upper CL)'
 UPIQ18 ='IQI #18 Gastrointestinal Hemorrhage Mortality Rate (Upper CL)'
 UPIQ19 ='IQI #19 Hip Fracture Mortality Rate (Upper CL)'
 UPIQ20 ='IQI #20 Pneumonia Mortality Rate (Upper CL)'
 UPIQ30 ='IQI #30 Percutaneous Coronary Intervention (PCI) Mortality Rate (Upper CL)'
 UPIQ31 ='IQI #31 Carotid Endarterectomy Mortality Rate (Upper CL)'
 UPIQ32 ='IQI #32 Acute Myocardial Infarction (AMI) Mortality Rate, Without Transfer Cases (Upper CL)'
 ;

 LABEL
 SPIQ08 ='IQI #8 Esophageal Resection Mortality Rate (Smoothed)'
 SPIQ09  ='IQI #9 Pancreatic Resection Mortality Rate (Smoothed)'
 SPIQ09A ='IQI #9 Pancreatic Resection Mortality Rate Stratum A (Smoothed)'
 SPIQ09B ='IQI #9 Pancreatic Resection Mortality Rate Stratum B (Smoothed)'
 SPIQ11  ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate (Smoothed)'
 SPIQ11A ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum A (Smoothed)'
 SPIQ11B ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum B (Smoothed)'
 SPIQ11C ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum C (Smoothed)'
 SPIQ11D ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum D (Smoothed)'
 SPIQ12 ='IQI #12 Coronary Artery Bypass Graft (CABG) Mortality Rate (Smoothed)'
 SPIQ13 ='IQI #13 Craniotomy Mortality Rate (Smoothed)'
 SPIQ14 ='IQI #14 Hip Replacement Mortality Rate (Smoothed)'
 SPIQ15 ='IQI #15 Acute Myocardial Infarction (AMI) Mortality Rate (Smoothed)'
 SPIQ16 ='IQI #16 Heart Failure Mortality Rate (Smoothed)'
 SPIQ17  ='IQI #17 Acute Stroke Mortality Rate (Smoothed)'
 SPIQ17A ='IQI #17 Acute Stroke Mortality Rate Stratum A (Smoothed)'
 SPIQ17B ='IQI #17 Acute Stroke Mortality Rate Stratum B (Smoothed)'
 SPIQ17C ='IQI #17 Acute Stroke Mortality Rate Stratum C (Smoothed)'
 SPIQ18 ='IQI #18 Gastrointestinal Hemorrhage Mortality Rate (Smoothed)'
 SPIQ19 ='IQI #19 Hip Fracture Mortality Rate (Smoothed)'
 SPIQ20 ='IQI #20 Pneumonia Mortality Rate (Smoothed)'
 SPIQ30 ='IQI #30 Percutaneous Coronary Intervention (PCI) Mortality Rate (Smoothed)'
 SPIQ31 ='IQI #31 Carotid Endarterectomy Mortality Rate (Smoothed)'
 SPIQ32 ='IQI #32 Acute Myocardial Infarction (AMI) Mortality Rate, Without Transfer Cases (Smoothed)'
 ;

 LABEL
 XPIQ08 ='IQI #8 Esophageal Resection Mortality Rate (Smthe SE)'
 XPIQ09  ='IQI #9 Pancreatic Resection Mortality Rate (Smthe SE)'
 XPIQ09A ='IQI #9 Pancreatic Resection Mortality Rate Stratum A (Smthe SE)'
 XPIQ09B ='IQI #9 Pancreatic Resection Mortality Rate Stratum B (Smthe SE)'
 XPIQ11  ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate (Smthe SE)'
 XPIQ11A ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum A (Smthe SE)'
 XPIQ11B ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum B (Smthe SE)'
 XPIQ11C ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum C (Smthe SE)'
 XPIQ11D ='IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum D (Smthe SE)'
 XPIQ12 ='IQI #12 Coronary Artery Bypass Graft (CABG) Mortality Rate (Smthe SE)'
 XPIQ13 ='IQI #13 Craniotomy Mortality Rate (Smthe SE)'
 XPIQ14 ='IQI #14 Hip Replacement Mortality Rate (Smthe SE)'
 XPIQ15 ='IQI #15 Acute Myocardial Infarction (AMI) Mortality Rate (Smthe SE)'
 XPIQ16 ='IQI #16 Heart Failure Mortality Rate (Smthe SE)'
 XPIQ17  ='IQI #17 Acute Stroke Mortality Rate (Smthe SE)'
 XPIQ17A ='IQI #17 Acute Stroke Mortality Rate Stratum A (Smthe SE)'
 XPIQ17B ='IQI #17 Acute Stroke Mortality Rate Stratum B (Smthe SE)'
 XPIQ17C ='IQI #17 Acute Stroke Mortality Rate Stratum C (Smthe SE)'
 XPIQ18 ='IQI #18 Gastrointestinal Hemorrhage Mortality Rate (Smthe SE)'
 XPIQ19 ='IQI #19 Hip Fracture Mortality Rate (Smthe SE)'
 XPIQ20 ='IQI #20 Pneumonia Mortality Rate (Smthe SE)'
 XPIQ30 ='IQI #30 Percutaneous Coronary Intervention (PCI) Mortality Rate (Smthe SE)'
 XPIQ31 ='IQI #31 Carotid Endarterectomy Mortality Rate (Smthe SE)'
 XPIQ32 ='IQI #32 Acute Myocardial Infarction (AMI) Mortality Rate, Without Transfer Cases (Smthe SE)'
 ;

 LABEL
 VPIQ08 = 'IQI #8 Esophageal Resection Mortality Rate (Variance)'
 VPIQ09 = 'IQI #9 Pancreatic Resection Mortality Rate (Variance)'
 VPIQ09A = 'IQI #9 Pancreatic Resection Mortality Rate Stratum A (Variance)'
 VPIQ09B = 'IQI #9 Pancreatic Resection Mortality Rate Stratum B (Variance)'
 VPIQ11 = 'IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate (Variance)'
 VPIQ11A = 'IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum A (Variance)'
 VPIQ11B = 'IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum B (Variance)'
 VPIQ11C = 'IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum C (Variance)'
 VPIQ11D = 'IQI #11 Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum D (Variance)'
 VPIQ12 = 'IQI #12 Coronary Artery Bypass Graft (CABG) Mortality Rate (Variance)'
 VPIQ13 = 'IQI #13 Craniotomy Mortality Rate (Variance)'
 VPIQ14 = 'IQI #14 Hip Replacement Mortality Rate (Variance)'
 VPIQ15 = 'IQI #15 Acute Myocardial Infarction (AMI) Mortality Rate (Variance)'
 VPIQ16 = 'IQI #16 Heart Failure Mortality Rate (Variance)'
 VPIQ17 = 'IQI #17 Acute Stroke Mortality Rate (Variance)'
 VPIQ17A = 'IQI #17 Acute Stroke Mortality Rate Stratum A (Variance)'
 VPIQ17B = 'IQI #17 Acute Stroke Mortality Rate Stratum B (Variance)'
 VPIQ17C = 'IQI #17 Acute Stroke Mortality Rate Stratum C (Variance)'
 VPIQ18 = 'IQI #18 Gastrointestinal Hemorrhage Mortality Rate (Variance)'
 VPIQ19 = 'IQI #19 Hip Fracture Mortality Rate (Variance)'
 VPIQ20 = 'IQI #20 Pneumonia Mortality Rate (Variance)'
 VPIQ30 = 'IQI #30 Percutaneous Coronary Intervention (PCI) Mortality Rate (Variance)'
 VPIQ31 = 'IQI #31 Carotid Endarterectomy Mortality Rate (Variance)'
 VPIQ32 = 'IQI #32 Acute Myocardial Infarction (AMI) Mortality Rate, Without Transfer Cases (Variance)'
 ;

 RUN;

*==================================================================;
*  Title:  PROGRAM P3  PART II:  MERGE PROVIDER RATES FOR AHRQ
*  INPATIENT QUALITY INDICATORS
*
*  Description:  MERGED RATES FOR INPATIENT QUALITY INDICATORS
*
*          >>>  VERSION 4.5, April 2013 <<<
*
*===================================================================;

 TITLE2 'PROGRAM P3 PART II';
 TITLE3 'AHRQ INPATIENT QUALITY INDICATORS: PROVIDER-LEVEL MERGED FILES';

 * ---------------------------------------------------------------- ;
 * --- INPATIENT QUALITY INDICATOR MERGED RATES                   - ;
 * ---------------------------------------------------------------- ;

 DATA &OUTFILP3.;
 MERGE INP2.&INFILEP2.
   (KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT _TYPE_ 
         TPIQ01 TPIQ02  TPIQ02A TPIQ02B TPIQ04 TPIQ04A TPIQ04B TPIQ04C TPIQ04D
         TPIQ05-TPIQ07  TPIQ21-TPIQ25 TPIQ33-TPIQ34 
         PPIQ21-PPIQ25  PPIQ33-PPIQ34 
         OPIQ21-OPIQ25  OPIQ33-OPIQ34)

       RISKADJ
   (KEEP=HOSPID AGECAT SEXCAT PAYCAT RACECAT 
         EPIQ08 EPIQ09  EPIQ09A EPIQ09B EPIQ11 EPIQ11A EPIQ11B EPIQ11C EPIQ11D EPIQ12-EPIQ16 EPIQ17 EPIQ17A EPIQ17B EPIQ17C EPIQ18-EPIQ20 EPIQ30-EPIQ32
         RPIQ08 RPIQ09  RPIQ09A RPIQ09B RPIQ11 RPIQ11A RPIQ11B RPIQ11C RPIQ11D RPIQ12-RPIQ16 RPIQ17 RPIQ17A RPIQ17B RPIQ17C RPIQ18-RPIQ20 RPIQ30-RPIQ32
		 LPIQ08 LPIQ09  LPIQ09A LPIQ09B LPIQ11 LPIQ11A LPIQ11B LPIQ11C LPIQ11D LPIQ12-LPIQ16 LPIQ17 LPIQ17A LPIQ17B LPIQ17C LPIQ18-LPIQ20 LPIQ30-LPIQ32
		 UPIQ08 UPIQ09  UPIQ09A UPIQ09B UPIQ11 UPIQ11A UPIQ11B UPIQ11C UPIQ11D UPIQ12-UPIQ16 UPIQ17 UPIQ17A UPIQ17B UPIQ17C UPIQ18-UPIQ20 UPIQ30-UPIQ32
		 SPIQ08 SPIQ09  SPIQ09A SPIQ09B SPIQ11 SPIQ11A SPIQ11B SPIQ11C SPIQ11D SPIQ12-SPIQ16 SPIQ17 SPIQ17A SPIQ17B SPIQ17C SPIQ18-SPIQ20 SPIQ30-SPIQ32
		 XPIQ08 XPIQ09  XPIQ09A XPIQ09B XPIQ11 XPIQ11A XPIQ11B XPIQ11C XPIQ11D XPIQ12-XPIQ16 XPIQ17 XPIQ17A XPIQ17B XPIQ17C XPIQ18-XPIQ20 XPIQ30-XPIQ32
		 VPIQ08 VPIQ09  VPIQ09A VPIQ09B VPIQ11 VPIQ11A VPIQ11B VPIQ11C VPIQ11D VPIQ12-VPIQ16 VPIQ17 VPIQ17A VPIQ17B VPIQ17C VPIQ18-VPIQ20 VPIQ30-VPIQ32
		 TPIQ08 TPIQ09  TPIQ09A TPIQ09B TPIQ11 TPIQ11A TPIQ11B TPIQ11C TPIQ11D TPIQ12-TPIQ16 TPIQ17 TPIQ17A TPIQ17B TPIQ17C TPIQ18-TPIQ20 TPIQ30-TPIQ32
		 PPIQ08 PPIQ09  PPIQ09A PPIQ09B PPIQ11 PPIQ11A PPIQ11B PPIQ11C PPIQ11D PPIQ12-PPIQ16 PPIQ17 PPIQ17A PPIQ17B PPIQ17C PPIQ18-PPIQ20 PPIQ30-PPIQ32
		 OPIQ08 OPIQ09  OPIQ09A OPIQ09B OPIQ11 OPIQ11A OPIQ11B OPIQ11C OPIQ11D OPIQ12-OPIQ16 OPIQ17 OPIQ17A OPIQ17B OPIQ17C OPIQ18-OPIQ20 OPIQ30-OPIQ32
         );
 BY HOSPID AGECAT SEXCAT PAYCAT RACECAT;

 %INCLUDE MSXP;

 ARRAY TRRY1{7} _TEMPORARY_ (22 23 24 25 26 30 31);
 ARRAY TRRY2{7}  OPIQ21 OPIQ22 OPIQ23 OPIQ24 OPIQ25 OPIQ33 OPIQ34;
 ARRAY TRRY3{7}  PPIQ21 PPIQ22 PPIQ23 PPIQ24 PPIQ25 PPIQ33 PPIQ34;
 ARRAY TRRY4{7}  EPIQ21 EPIQ22 EPIQ23 EPIQ24 EPIQ25 EPIQ33 EPIQ34;
 ARRAY TRRY5{7}  RPIQ21 RPIQ22 RPIQ23 RPIQ24 RPIQ25 RPIQ33 RPIQ34;
 ARRAY TRRY6{7}  SEIQ21 SEIQ22 SEIQ23 SEIQ24 SEIQ25 SEIQ33 SEIQ34;
 ARRAY TRRY7{7}  VPIQ21 VPIQ22 VPIQ23 VPIQ24 VPIQ25 VPIQ33 VPIQ34;
 ARRAY TRRY8{7}  SNIQ21 SNIQ22 SNIQ23 SNIQ24 SNIQ25 SNIQ33 SNIQ34;
 ARRAY TRRY9{7}  SPIQ21 SPIQ22 SPIQ23 SPIQ24 SPIQ25 SPIQ33 SPIQ34;
 ARRAY TRRY10{7} XPIQ21 XPIQ22 XPIQ23 XPIQ24 XPIQ25 XPIQ33 XPIQ34;
 ARRAY TRRY11{7} LPIQ21 LPIQ22 LPIQ23 LPIQ24 LPIQ25 LPIQ33 LPIQ34;
 ARRAY TRRY12{7} UPIQ21 UPIQ22 UPIQ23 UPIQ24 UPIQ25 UPIQ33 UPIQ34;

 DO I = 1 TO 7;
    TRRY4(I) = ARRYP3(TRRY1(I));
    IF AGECAT = . AND SEXCAT = . AND PAYCAT = . AND RACECAT = . THEN DO;
       TRRY5(I)  = TRRY2(I);
       TRRY6(I)  = SQRT(TRRY2(I)*(1-TRRY2(I)) / TRRY3(I));
       TRRY7(I)  = TRRY6(I)**2;
       TRRY8(I)  = ARRYP2(TRRY1(I)) / (ARRYP2(TRRY1(I)) + TRRY7(I));
       TRRY9(I)  = (TRRY5(I) * TRRY8(I)) + ((1 -  TRRY8(I)) *  ARRYP3(TRRY1(I)));
       TRRY10(I)  = SQRT(ARRYP2(TRRY1(I))- (TRRY8(I) * ARRYP2(TRRY1(I))));
    END;
    ELSE DO;
       TRRY5(I)  = (TRRY2(I) / TRRY4(I));
       TRRY6(I)  = SQRT(TRRY2(I)*(1-TRRY2(I)) / TRRY3(I)) / TRRY4(I);
       TRRY7(I)  = .;
       TRRY9(I)  = .;
       TRRY10(I)  = .;
    END;
    TRRY11(I)   = TRRY5(I) - (1.96 * TRRY6(I));
    IF TRRY11(I) < 0 THEN TRRY11(I) = 0;
    TRRY12(I)   = TRRY5(I) + (1.96 * TRRY6(I));
    IF TRRY12(I) > 1 THEN TRRY12(I) = 1;
 END;

 LABEL
 EPIQ21 ='IQI #21 Cesarean Delivery Rate, Uncomplicated (Expected)'
 EPIQ22 ='IQI #22 Vaginal Birth After Cesarean (VBAC) Delivery Rate, Uncomplicated (Expected)'
 EPIQ23 ='IQI #23 Laparoscopic Cholecystectomy Rate (Expected)'
 EPIQ24 ='IQI #24 Incidental Appendectomy in the Elderly Rate (Expected)'
 EPIQ25 ='IQI #25 Bilateral Cardiac Catheterization Rate (Expected)'
 EPIQ33 ='IQI #33 Primary Cesarean Delivery Rate, Uncomplicated (Expected)'
 EPIQ34 ='IQI #34 Vaginal Birth After Cesarean (VBAC) Rate, All (Expected)'
 ;

 LABEL
 RPIQ21 ='IQI #21 Cesarean Delivery Rate, Uncomplicated (Risk Adj)'
 RPIQ22 ='IQI #22 Vaginal Birth After Cesarean (VBAC) Delivery Rate, Uncomplicated (Risk Adj)'
 RPIQ23 ='IQI #23 Laparoscopic Cholecystectomy Rate (Risk Adj)'
 RPIQ24 ='IQI #24 Incidental Appendectomy in the Elderly Rate (Risk Adj)'
 RPIQ25 ='IQI #25 Bilateral Cardiac Catheterization Rate (Risk Adj)'
 RPIQ33 ='IQI #33 Primary Cesarean Delivery Rate, Uncomplicated (Risk Adj)'
 RPIQ34 ='IQI #34 Vaginal Birth After Cesarean (VBAC) Rate, All (Risk Adj)'
 ;

 LABEL
 LPIQ21 ='IQI #21 Cesarean Delivery Rate, Uncomplicated (Lower CL)'
 LPIQ22 ='IQI #22 Vaginal Birth After Cesarean (VBAC) Delivery Rate, Uncomplicated (Lower CL)'
 LPIQ23 ='IQI #23 Laparoscopic Cholecystectomy Rate (Lower CL)'
 LPIQ24 ='IQI #24 Incidental Appendectomy in the Elderly Rate (Lower CL)'
 LPIQ25 ='IQI #25 Bilateral Cardiac Catheterization Rate (Lower CL)'
 LPIQ33 ='IQI #33 Primary Cesarean Delivery Rate, Uncomplicated (Lower CL)'
 LPIQ34 ='IQI #34 Vaginal Birth After Cesarean (VBAC) Rate, All (Lower CL)'
 ;

 LABEL
 UPIQ21 ='IQI #21 Cesarean Delivery Rate, Uncomplicated (Upper CL)'
 UPIQ22 ='IQI #22 Vaginal Birth After Cesarean (VBAC) Delivery Rate, Uncomplicated (Upper CL)'
 UPIQ23 ='IQI #23 Laparoscopic Cholecystectomy Rate (Upper CL)'
 UPIQ24 ='IQI #24 Incidental Appendectomy in the Elderly Rate (Upper CL)'
 UPIQ25 ='IQI #25 Bilateral Cardiac Catheterization Rate (Upper CL)'
 UPIQ33 ='IQI #33 Primary Cesarean Delivery Rate, Uncomplicated (Upper CL)'
 UPIQ34 ='IQI #34 Vaginal Birth After Cesarean (VBAC) Rate, All (Upper CL)'
 ;

 LABEL
 SPIQ21 ='IQI #21 Cesarean Delivery Rate, Uncomplicated (Smoothed)'
 SPIQ22 ='IQI #22 Vaginal Birth After Cesarean (VBAC) Delivery Rate, Uncomplicated (Smoothed)'
 SPIQ23 ='IQI #23 Laparoscopic Cholecystectomy Rate (Smoothed)'
 SPIQ24 ='IQI #24 Incidental Appendectomy in the Elderly Rate (Smoothed)'
 SPIQ25 ='IQI #25 Bilateral Cardiac Catheterization Rate (Smoothed)'
 SPIQ33 ='IQI #33 Primary Cesarean Delivery Rate, Uncomplicated (Smoothed)'
 SPIQ34 ='IQI #34 Vaginal Birth After Cesarean (VBAC) Rate, All (Smoothed)'
 ;

 LABEL
 XPIQ21 ='IQI #21 Cesarean Delivery Rate, Uncomplicated (Smthe SE)'
 XPIQ22 ='IQI #22 Vaginal Birth After Cesarean (VBAC) Delivery Rate, Uncomplicated (Smthe SE)'
 XPIQ23 ='IQI #23 Laparoscopic Cholecystectomy Rate (Smthe SE)'
 XPIQ24 ='IQI #24 Incidental Appendectomy in the Elderly Rate (Smthe SE)'
 XPIQ25 ='IQI #25 Bilateral Cardiac Catheterization Rate (Smthe SE)'
 XPIQ33 ='IQI #33 Primary Cesarean Delivery Rate, Uncomplicated (Smthe SE)'
 XPIQ34 ='IQI #34 Vaginal Birth After Cesarean (VBAC) Rate, All (Smthe SE)'
 ;

 LABEL
 VPIQ21 = 'IQI #21 Cesarean Delivery Rate, Uncomplicated (Variance)'
 VPIQ22 = 'IQI #22 Vaginal Birth After Cesarean (VBAC) Delivery Rate, Uncomplicated (Variance)'
 VPIQ23 = 'IQI #23 Laparoscopic Cholecystectomy Rate (Variance)'
 VPIQ24 = 'IQI #24 Incidental Appendectomy in the Elderly Rate (Variance)'
 VPIQ25 = 'IQI #25 Bilateral Cardiac Catheterization Rate (Variance)'
 VPIQ33 = 'IQI #33 Primary Cesarean Delivery Rate, Uncomplicated (Variance)'
 VPIQ34 = 'IQI #34 Vaginal Birth After Cesarean (VBAC) Rate, All (Variance)'
 ;

 ARRAY ARRY1{31} EPIQ08-EPIQ09 EPIQ09A EPIQ09B EPIQ11 EPIQ11A EPIQ11B EPIQ11C EPIQ11D EPIQ12-EPIQ17 EPIQ17A EPIQ17B EPIQ17C EPIQ18-EPIQ25 EPIQ30-EPIQ34;
 ARRAY ARRY2{31} RPIQ08-RPIQ09 RPIQ09A RPIQ09B RPIQ11 RPIQ11A RPIQ11B RPIQ11C RPIQ11D RPIQ12-RPIQ17 RPIQ17A RPIQ17B RPIQ17C RPIQ18-RPIQ25 RPIQ30-RPIQ34;
 ARRAY ARRY3{31} LPIQ08-LPIQ09 LPIQ09A LPIQ09B LPIQ11 LPIQ11A LPIQ11B LPIQ11C LPIQ11D LPIQ12-LPIQ17 LPIQ17A LPIQ17B LPIQ17C LPIQ18-LPIQ25 LPIQ30-LPIQ34;
 ARRAY ARRY4{31} UPIQ08-UPIQ09 UPIQ09A UPIQ09B UPIQ11 UPIQ11A UPIQ11B UPIQ11C UPIQ11D UPIQ12-UPIQ17 UPIQ17A UPIQ17B UPIQ17C UPIQ18-UPIQ25 UPIQ30-UPIQ34;
 ARRAY ARRY5{31} SPIQ08-SPIQ09 SPIQ09A SPIQ09B SPIQ11 SPIQ11A SPIQ11B SPIQ11C SPIQ11D SPIQ12-SPIQ17 SPIQ17A SPIQ17B SPIQ17C SPIQ18-SPIQ25 SPIQ30-SPIQ34;
 ARRAY ARRY6{31} XPIQ08-XPIQ09 XPIQ09A XPIQ09B XPIQ11 XPIQ11A XPIQ11B XPIQ11C XPIQ11D XPIQ12-XPIQ17 XPIQ17A XPIQ17B XPIQ17C XPIQ18-XPIQ25 XPIQ30-XPIQ34;
 ARRAY ARRY7{31} VPIQ08-VPIQ09 VPIQ09A VPIQ09B VPIQ11 VPIQ11A VPIQ11B VPIQ11C VPIQ11D VPIQ12-VPIQ17 VPIQ17A VPIQ17B VPIQ17C VPIQ18-VPIQ25 VPIQ30-VPIQ34;
 ARRAY ARRY8{31} PPIQ08-PPIQ09 PPIQ09A PPIQ09B PPIQ11 PPIQ11A PPIQ11B PPIQ11C PPIQ11D PPIQ12-PPIQ17 PPIQ17A PPIQ17B PPIQ17C PPIQ18-PPIQ25 PPIQ30-PPIQ34;

 DO I = 1 TO 31;
   IF ARRY8(I) <= 2 THEN DO;
      ARRY1(I) = .; ARRY2(I) = .; ARRY3(I) = .; ARRY4(I) = .;
      ARRY5(I) = .; ARRY6(I) = .; ARRY7(I) = .; 
   END;
 END;

 DROP I;
    
 FORMAT EPIQ08  EPIQ09  EPIQ09A EPIQ09B EPIQ11 EPIQ11A EPIQ11B EPIQ11C EPIQ11D EPIQ12 EPIQ13 EPIQ14 EPIQ15 EPIQ16 
		EPIQ17  EPIQ17A EPIQ17B EPIQ17C EPIQ18 EPIQ19  EPIQ20  EPIQ21  EPIQ22  EPIQ23 EPIQ24 
		EPIQ25  EPIQ30  EPIQ31  EPIQ32  EPIQ33 EPIQ34

		LPIQ08  LPIQ09  LPIQ09A LPIQ09B LPIQ11 LPIQ11A LPIQ11B LPIQ11C LPIQ11D LPIQ12 LPIQ13 LPIQ14 LPIQ15 LPIQ16
		LPIQ17  LPIQ17A LPIQ17B LPIQ17C LPIQ18 LPIQ19  LPIQ20  LPIQ21  LPIQ22  LPIQ23 LPIQ24
		LPIQ25  LPIQ30  LPIQ31  LPIQ32  LPIQ33 LPIQ34 

		OPIQ08  OPIQ09  OPIQ09A OPIQ09B OPIQ11 OPIQ11A OPIQ11B OPIQ11C OPIQ11D OPIQ12 OPIQ13 OPIQ14 OPIQ15 OPIQ16
		OPIQ17  OPIQ17A OPIQ17B OPIQ17C OPIQ18 OPIQ19  OPIQ20  OPIQ21  OPIQ22  OPIQ23 OPIQ24
		OPIQ25  OPIQ30  OPIQ31  OPIQ32  OPIQ33 OPIQ34 

		RPIQ08  RPIQ09  RPIQ09A RPIQ09B RPIQ11 RPIQ11A RPIQ11B RPIQ11C RPIQ11D RPIQ12 RPIQ13 RPIQ14 RPIQ15 RPIQ16
		RPIQ17  RPIQ17A RPIQ17B RPIQ17C RPIQ18 RPIQ19  RPIQ20  RPIQ21  RPIQ22  RPIQ23 RPIQ24
		RPIQ25  RPIQ30  RPIQ31  RPIQ32  RPIQ33 RPIQ34 

		SEIQ21 SEIQ22 SEIQ23 SEIQ24 SEIQ25 SEIQ33 SEIQ34
		SNIQ21 SNIQ22 SNIQ23 SNIQ24 SNIQ25 SNIQ33 SNIQ34

		SPIQ08  SPIQ09  SPIQ09A SPIQ09B SPIQ11 SPIQ11A SPIQ11B SPIQ11C SPIQ11D SPIQ12 SPIQ13 SPIQ14 SPIQ15 SPIQ16
		SPIQ17  SPIQ17A SPIQ17B SPIQ17C SPIQ18 SPIQ19  SPIQ20  SPIQ21  SPIQ22  SPIQ23 SPIQ24
		SPIQ25  SPIQ30  SPIQ31  SPIQ32  SPIQ33 SPIQ34

		UPIQ08  UPIQ09  UPIQ09A UPIQ09B UPIQ11 UPIQ11A UPIQ11B UPIQ11C UPIQ11D UPIQ12 UPIQ13 UPIQ14 UPIQ15 UPIQ16
		UPIQ17  UPIQ17A UPIQ17B UPIQ17C UPIQ18 UPIQ19  UPIQ20  UPIQ21  UPIQ22  UPIQ23 UPIQ24
		UPIQ25  UPIQ30  UPIQ31  UPIQ32  UPIQ33 UPIQ34 

		VPIQ08  VPIQ09  VPIQ09A VPIQ09B VPIQ11 VPIQ11A VPIQ11B VPIQ11C VPIQ11D VPIQ12 VPIQ13 VPIQ14 VPIQ15 VPIQ16 
		VPIQ17  VPIQ17A VPIQ17B VPIQ17C VPIQ18 VPIQ19  VPIQ20  VPIQ21  VPIQ22  VPIQ23 VPIQ24
		VPIQ25  VPIQ30  VPIQ31  VPIQ32  VPIQ33 VPIQ34 

		XPIQ08  XPIQ09  XPIQ09A XPIQ09B XPIQ11 XPIQ11A XPIQ11B XPIQ11C XPIQ11D XPIQ12 XPIQ13 XPIQ14 XPIQ15 XPIQ16
		XPIQ17  XPIQ17A XPIQ17B XPIQ17C XPIQ18 XPIQ19  XPIQ20  XPIQ21  XPIQ22  XPIQ23 XPIQ24
		XPIQ25  XPIQ30  XPIQ31  XPIQ32  XPIQ33 XPIQ34 13.7

		TPIQ01  TPIQ02  TPIQ02A TPIQ02B TPIQ04  TPIQ04A TPIQ04B TPIQ04C TPIQ04D TPIQ05 TPIQ06 TPIQ07  TPIQ08  TPIQ09  TPIQ09A TPIQ09B
		TPIQ11  TPIQ11A TPIQ11B TPIQ11C TPIQ11D TPIQ12  TPIQ13  TPIQ14  TPIQ15  TPIQ16 TPIQ17 TPIQ17A TPIQ17B TPIQ17C TPIQ18
		TPIQ19  TPIQ20  TPIQ21  TPIQ22  TPIQ23  TPIQ24  TPIQ25  TPIQ30
		TPIQ31  TPIQ32  TPIQ33  TPIQ34 

		PPIQ08  PPIQ09  PPIQ09A PPIQ09B PPIQ11 PPIQ11A PPIQ11B PPIQ11C PPIQ11D PPIQ12 PPIQ13 PPIQ14 PPIQ15 PPIQ16
		PPIQ17  PPIQ17A PPIQ17B PPIQ17C PPIQ18 PPIQ19  PPIQ20  PPIQ21  PPIQ22  PPIQ23 PPIQ24
		PPIQ25  PPIQ30  PPIQ31  PPIQ32  PPIQ33 PPIQ34 13.0;

 RUN;

 /***------------------------------------------------------------------------------------------------------------------
    Provider-level indicators which are utilization or process measures: IQI 321, 22, 23, 24, 25, 33 and 34 are not 
    risk adjusted in the software because risk-adjustment is not appropriate.   For these indicators, the 
    observed rate is the applicable measure of performance, and the expected, risk-adjusted, and smoothed rates provide 
    no additional information. Starting in version 4.5, the values for those rates will be set to be missing.
 ---------------------------------------------------------------------------------------------------------------------***/

DATA OUTP3.&OUTFILP3.;
SET  &OUTFILP3.;

     EPIQ21 = .;
	 EPIQ22 = .;
	 EPIQ23 = .;
	 EPIQ24 = .;
	 EPIQ25 = .;
	 EPIQ33 = .;
	 EPIQ34 = .;

	 RPIQ21 = .;
	 RPIQ22 = .;
	 RPIQ23 = .;
	 RPIQ24 = .;
	 RPIQ25 = .;
	 RPIQ33 = .;
	 RPIQ34 = .;

	 LPIQ21 = .;
	 LPIQ22 = .;
	 LPIQ23 = .;
	 LPIQ24 = .;
	 LPIQ25 = .;
	 LPIQ33 = .;
	 LPIQ34 = .;
	 
	 UPIQ21 = .;
	 UPIQ22 = .;
	 UPIQ23 = .;
	 UPIQ24 = .;
	 UPIQ25 = .;
	 UPIQ33 = .;
	 UPIQ34 = .;

	 SEIQ21 = .;
	 SEIQ22 = .;
	 SEIQ23 = .;
	 SEIQ24 = .;
	 SEIQ25 = .;
	 SEIQ33 = .;
	 SEIQ34 = .;

	 SPIQ21 = .;
	 SPIQ22 = .;
	 SPIQ23 = .;
	 SPIQ24 = .;
	 SPIQ25 = .;
	 SPIQ33 = .;
	 SPIQ34 = .;

	 SNIQ21 = .;
	 SNIQ22 = .;
	 SNIQ23 = .;
	 SNIQ24 = .;
	 SNIQ25 = .;
	 SNIQ33 = .;
	 SNIQ34 = .;

	 XPIQ21 = .;
	 XPIQ22 = .;
	 XPIQ23 = .;
	 XPIQ24 = .;
	 XPIQ25 = .;
	 XPIQ33 = .;
	 XPIQ34 = .;

	 VPIQ21 = .; 
     VPIQ22 = .; 
     VPIQ23 = .; 
     VPIQ24 = .; 
     VPIQ25 = .; 
     VPIQ33 = .; 
     VPIQ34 = .; 
RUN;
 * -------------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF PROVIDER-LEVEL MERGED FILE --------- ;
 * -------------------------------------------------------------- ;

 PROC CONTENTS DATA=OUTP3.&OUTFILP3. POSITION;
 RUN;

 PROC MEANS DATA=OUTP3.&OUTFILP3. (WHERE=(_TYPE_ IN (16))) N NMISS MIN MAX MEAN SUM NOLABELS;
 TITLE4 "SUMMARY OF PROVIDER-LEVEL RATES (_TYPE_=16)";
 RUN;


 * -------------------------------------------------------------- ;
 * --- PRINT PROVIDER MERGED FILE ------------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(IQ,TEXT,VOLUME);

 PROC  PRINT DATA=OUTP3.&OUTFILP3. LABEL SPLIT='*';
 %IF   &VOLUME = 0 %THEN %DO;
 VAR   HOSPID AGECAT SEXCAT PAYCAT RACECAT 
       TPIQ&IQ. PPIQ&IQ. OPIQ&IQ. EPIQ&IQ. RPIQ&IQ. LPIQ&IQ. UPIQ&IQ. SPIQ&IQ. XPIQ&IQ.;
 LABEL HOSPID  = "HOSPID"
       AGECAT  = "AGECAT"
       SEXCAT  = "SEXCAT"
       PAYCAT  = "PAYCAT"
       RACECAT = "RACECAT"
       TPIQ&IQ.   = "TPIQ&IQ.*(Numerator)"
       PPIQ&IQ.   = "PPIQ&IQ.*(Denominator)"
       OPIQ&IQ.   = "OPIQ&IQ.*(Observed)"
       EPIQ&IQ.   = "EPIQ&IQ.*(Expected)"
       RPIQ&IQ.   = "RPIQ&IQ.*(Risk Adj)"
       LPIQ&IQ.   = "LPIQ&IQ.*(Lower CL)"
       UPIQ&IQ.   = "UPIQ&IQ.*(Upper CL)"
       SPIQ&IQ.   = "SPIQ&IQ.*(Smoothed)"
       XPIQ&IQ.   = "XPIQ&IQ.*(Smthe SE)"
       ;
 FORMAT AGECAT AGECAT.
        SEXCAT SEXCAT.
        PAYCAT PAYCAT.
        RACECAT RACECAT.
        TPIQ&IQ. PPIQ&IQ. 13.0 OPIQ&IQ. EPIQ&IQ. RPIQ&IQ. LPIQ&IQ. UPIQ&IQ. SPIQ&IQ. XPIQ&IQ. 8.6;
 %END;
 %ELSE %DO;
 VAR   HOSPID AGECAT SEXCAT PAYCAT RACECAT TPIQ&IQ.;
 LABEL HOSPID   = "HOSPID"
       AGECAT  = "AGECAT"
       SEXCAT  = "SEXCAT"
       PAYCAT  = "PAYCAT"
       RACECAT = "RACECAT"
       TPIQ&IQ. = "TPIQ&IQ.*(Numerator)"
       ;
 FORMAT AGECAT AGECAT.
        SEXCAT SEXCAT.
        PAYCAT PAYCAT.
        RACECAT RACECAT.
        TPIQ&IQ. 13.0;
 %END;
 TITLE4 "FINAL OUTPUT";
 TITLE5 "Indicator # &IQ.: &TEXT";

 RUN;

 %MEND PRT;

 %PRT(01, Esophageal Resection Volume,1);
 %PRT(02, Pancreatic Resection Volume,1);
 %PRT(02A, Pancreatic Resection Volume Stratum A,1);
 %PRT(02B, Pancreatic Resection Volume Stratum B,1);
 %PRT(04, Abdominal Aortic Aneurysm (AAA) Repair Volume,1);
 %PRT(04A, Abdominal Aortic Aneurysm (AAA) Repair Volume Stratum A,1);
 %PRT(04B, Abdominal Aortic Aneurysm (AAA) Repair Volume Stratum B,1);
 %PRT(04C, Abdominal Aortic Aneurysm (AAA) Repair Volume Stratum C,1);
 %PRT(04D, Abdominal Aortic Aneurysm (AAA) Repair Volume Stratum D,1);
 %PRT(05, Coronary Artery Bypass Graft (CABG) Volume,1); 
 %PRT(06, Percutaneous Coronary Intervention (PCI) Volume,1);
 %PRT(07, Carotid Endarterectomy Volume,1);
 %PRT(08, Esophageal Resection Mortality Rate,0);
 %PRT(09, Pancreatic Resection Mortality Rate,0);
 %PRT(09A, Pancreatic Resection Mortality Rate Stratum A,0);
 %PRT(09B, Pancreatic Resection Mortality Rate Stratum B,0);
 %PRT(11, Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate,0);
 %PRT(11A, Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum A,0);
 %PRT(11B, Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum B,0);
 %PRT(11C, Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum C,0);
 %PRT(11D, Abdominal Aortic Aneurysm (AAA) Repair Mortality Rate Stratum D,0);
 %PRT(12, Coronary Artery Bypass Graft (CABG) Mortality Rate,0);
 %PRT(13, Craniotomy Mortality Rate,0);
 %PRT(14, Hip Replacement Mortality Rate,0);
 %PRT(15, Acute Myocardial Infarction (AMI) Mortality Rate,0);
 %PRT(16, Heart Failure Mortality Rate,0);
 %PRT(17, Acute Stroke Mortality Rate,0);
 %PRT(17A, Acute Stroke Mortality Rate Stratum A,0);
 %PRT(17B, Acute Stroke Mortality Rate Stratum B,0);
 %PRT(17C, Acute Stroke Mortality Rate Stratum C,0);
 %PRT(18, Gastrointestinal Hemorrhage Mortality Rate,0);
 %PRT(19, Hip Fracture Mortality Rate,0);
 %PRT(20, Pneumonia Mortality Rate,0);
 %PRT(21, %BQUOTE(Cesarean Delivery Rate, Uncomplicated),0);
 %PRT(22, %BQUOTE(Vaginal Birth After Cesarean (VBAC) Delivery Rate, Uncomplicated),0);
 %PRT(23, Laparoscopic Cholecystectomy Rate,0);
 %PRT(24, Incidental Appendectomy in the Elderly Rate,0);
 %PRT(25, Bilateral Cardiac Catheterization Rate,0);
 %PRT(30, Percutaneous Coronary Intervention (PCI) Mortality Rate,0);
 %PRT(31, Carotid Endarterectomy Mortality Rate,0);
 %PRT(32, %BQUOTE(Acute Myocardial Infarction (AMI) Mortality Rate, Without Transfer Cases),0);
 %PRT(33, %BQUOTE(Primary Cesarean Delivery Rate, Uncomplicated),0);
 %PRT(34, %BQUOTE(Vaginal Birth After Cesarean (VBAC) Rate, All),0);

 %END;

 %MEND PRT2;

 %PRT2;

 * -------------------------------------------------------------- ;
 * --- WRITE SAS OUTPUT DATA SET TO COMMA-DELIMITED TEXT FILE --- ;
 * --- FOR EXPORT INTO SPREADSHEETS ----------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO TEXT;

 %IF &TEXTP3. = 1 %THEN %DO;

 DATA _NULL_;
 SET OUTP3.&OUTFILP3;
 FILE IQTEXTP3 LRECL=4000;
 IF _N_=1 THEN PUT 
 "Hosp Id" ","  "Age"     "," "Sex"     "," "Payer"   "," "Race"  "," "Type" ","
 "TPIQ01"  ","  "TPIQ02"  "," "TPIQ02A" "," "TPIQ02B" "," 
 "TPIQ04"  ","  "TPIQ04A" "," "TPIQ04B" "," "TPIQ04C"  "," "TPIQ04D"  ","  
 "TPIQ05"  ","  "TPIQ06"  "," "TPIQ07"  "," 
 "TPIQ08"  ","  "TPIQ09"  "," "TPIQ09A" "," "TPIQ09B" "," 
 "TPIQ11"  ","  "TPIQ11A" "," "TPIQ11B" "," "TPIQ11C" "," "TPIQ11D" ","
 "TPIQ12"  ","  "TPIQ13"  "," "TPIQ14"  "," "TPIQ15"  "," "TPIQ16"  "," 
 "TPIQ17"  ","  "TPIQ17A" "," "TPIQ17B" "," "TPIQ17C" "," "TPIQ18"  "," "TPIQ19"  "," 
 "TPIQ20"  ","  "TPIQ21"  "," "TPIQ22"  "," "TPIQ23"  "," "TPIQ24"  ","
 "TPIQ25"  ","  "TPIQ30"  "," "TPIQ31"  "," "TPIQ32"  "," "TPIQ33"  ","  
 "TPIQ34"  "," 
 "PPIQ08"  ","  "PPIQ09"  "," "PPIQ09A" "," "PPIQ09B" ","
 "PPIQ11"  ","  "PPIQ11A" "," "PPIQ11B" "," "PPIQ11C" "," "PPIQ11D" ","  
 "PPIQ12"  ","  "PPIQ13"  "," "PPIQ14"  "," "PPIQ15"  "," "PPIQ16"  ","
 "PPIQ17"  ","  "PPIQ17A" "," "PPIQ17B" "," "PPIQ17C" "," "PPIQ18"  ","
 "PPIQ19"  ","  "PPIQ20"  "," "PPIQ21"  "," "PPIQ22"  "," "PPIQ23"  ","
 "PPIQ24"  ","  "PPIQ25"  "," "PPIQ30"  "," "PPIQ31"  "," "PPIQ32"  "," 
 "PPIQ33"  ","  "PPIQ34"  ","
 "OPIQ08"  ","  "OPIQ09"  "," "OPIQ09A" "," "OPIQ09B" "," 
 "OPIQ11"  ","  "OPIQ11A" "," "OPIQ11B" "," "OPIQ11C" "," "OPIQ11D" "," 
 "OPIQ12"  ","  "OPIQ13"  "," "OPIQ14"  "," "OPIQ15"  "," "OPIQ16"  ","
 "OPIQ17"  ","  "OPIQ17A" "," "OPIQ17B" "," "OPIQ17C" "," "OPIQ18"  "," 
 "OPIQ19"  ","  "OPIQ20"  "," "OPIQ21"  "," "OPIQ22"  "," "OPIQ23"  "," 
 "OPIQ24"  ","  "OPIQ25"  "," "OPIQ30"  "," "OPIQ31"  "," "OPIQ32"  "," 
 "OPIQ33"  ","  "OPIQ34"  ","
 "EPIQ08"  ","  "EPIQ09"  "," "EPIQ09A" "," "EPIQ09B" "," 
 "EPIQ11"  ","  "EPIQ11A" "," "EPIQ11B" "," "EPIQ11C" "," "EPIQ11D" "," 
 "EPIQ12"  ","  "EPIQ13"  "," "EPIQ14"  "," "EPIQ15"  "," "EPIQ16"  ","
 "EPIQ17"  ","  "EPIQ17A" "," "EPIQ17B" "," "EPIQ17C" "," "EPIQ18"  "," 
 "EPIQ19"  ","  "EPIQ20"  "," "EPIQ21"  "," "EPIQ22"  "," "EPIQ23"  "," 
 "EPIQ24"  ","  "EPIQ25"  "," "EPIQ30"  "," "EPIQ31"  "," "EPIQ32"  "," 
 "EPIQ33"  ","  "EPIQ34"  ","
 "RPIQ08"  ","  "RPIQ09"  "," "RPIQ09A" "," "RPIQ09B" "," 
 "RPIQ11"  ","  "RPIQ11A" "," "RPIQ11B" "," "RPIQ11C" "," "RPIQ11D" "," 
 "RPIQ12"  ","  "RPIQ13"  "," "RPIQ14"  "," "RPIQ15"  "," "RPIQ16"  ","
 "RPIQ17"  ","  "RPIQ17A" "," "RPIQ17B" "," "RPIQ17C" "," "RPIQ18"  "," 
 "RPIQ19"  ","  "RPIQ20"  "," "RPIQ21"  "," "RPIQ22"  "," "RPIQ23"  "," 
 "RPIQ24"  ","  "RPIQ25"  "," "RPIQ30"  "," "RPIQ31"  "," "RPIQ32"  "," 
 "RPIQ33"  ","  "RPIQ34"  ","
 "LPIQ08"  ","  "LPIQ09"  "," "LPIQ09A" "," "LPIQ09B" "," 
 "LPIQ11"  ","  "LPIQ11A" "," "LPIQ11B" "," "LPIQ11C" "," "LPIQ11D" ","
 "LPIQ12"  ","  "LPIQ13"  "," "LPIQ14"  "," "LPIQ15"  "," "LPIQ16"  ","
 "LPIQ17"  ","  "LPIQ17A" "," "LPIQ17B" "," "LPIQ17C" "," "LPIQ18"  ","
 "LPIQ19"  ","  "LPIQ20"  "," "LPIQ21"  "," "LPIQ22"  "," "LPIQ23"  ","
 "LPIQ24"  ","  "LPIQ25"  "," "LPIQ30"  "," "LPIQ31"  "," "LPIQ32"  "," 
 "LPIQ33"  ","  "LPIQ34"  ","
 "UPIQ08"  ","  "UPIQ09"  "," "UPIQ09A" "," "UPIQ09B" ","  
 "UPIQ11"  ","  "UPIQ11A" "," "UPIQ11B" "," "UPIQ11C" "," "UPIQ11D" ","  
 "UPIQ12"  ","  "UPIQ13"  "," "UPIQ14"  "," "UPIQ15"  "," "UPIQ16"  ","
 "UPIQ17"  ","  "UPIQ17A" "," "UPIQ17B" "," "UPIQ17C" "," "UPIQ18"  ","  
 "UPIQ19"  ","  "UPIQ20"  "," "UPIQ21"  "," "UPIQ22"  "," "UPIQ23"  "," 
 "UPIQ24"  ","  "UPIQ25"  "," "UPIQ30"  "," "UPIQ31"  "," "UPIQ32"  "," 
 "UPIQ33"  ","  "UPIQ34"  ","
 "SPIQ08"  ","  "SPIQ09"  "," "SPIQ09A" "," "SPIQ09B" "," 
 "SPIQ11"  ","  "SPIQ11A" "," "SPIQ11B" "," "SPIQ11C" "," "SPIQ11D" "," 
 "SPIQ12"  ","  "SPIQ13"  "," "SPIQ14"  "," "SPIQ15"  "," "SPIQ16"  ","
 "SPIQ17"  ","  "SPIQ17A" "," "SPIQ17B" "," "SPIQ17C" "," "SPIQ18"  "," 
 "SPIQ19"  ","  "SPIQ20"  "," "SPIQ21"  "," "SPIQ22"  "," "SPIQ23"  ","
 "SPIQ24"  ","  "SPIQ25"  "," "SPIQ30"  "," "SPIQ31"  "," "SPIQ32"  "," 
 "SPIQ33"  ","  "SPIQ34"  "," 
 "XPIQ08"  ","  "XPIQ09"  "," "XPIQ09A" "," "XPIQ09B" "," 
 "XPIQ11"  ","  "XPIQ11A" "," "XPIQ11B" "," "XPIQ11C" "," "XPIQ11D" "," 
 "XPIQ12"  ","  "XPIQ13"  "," "XPIQ14"  "," "XPIQ15"  "," "XPIQ16"  ","
 "XPIQ17"  ","  "XPIQ17A" "," "XPIQ17B" "," "XPIQ17C" "," "XPIQ18"  "," 
 "XPIQ19"  ","  "XPIQ20"  "," "XPIQ21"  "," "XPIQ22"  "," "XPIQ23"  "," 
 "XPIQ24"  ","  "XPIQ25"  "," "XPIQ30"  "," "XPIQ31"  "," "XPIQ32"  "," 
 "XPIQ33"  ","  "XPIQ34"  
 ;

 PUT HOSPID 13. "," AGECAT 3.  "," SEXCAT 3. "," PAYCAT 3. "," RACECAT 3. "," _TYPE_ 2.  ","
 (TPIQ01-TPIQ02 TPIQ02A TPIQ02B TPIQ04 TPIQ04A TPIQ04B TPIQ04C TPIQ04D
  TPIQ05-TPIQ09 TPIQ09A TPIQ09B TPIQ11 TPIQ11A TPIQ11B TPIQ11C TPIQ11D
  TPIQ12-TPIQ17 TPIQ17A TPIQ17B TPIQ17C TPIQ18-TPIQ25  TPIQ30-TPIQ34) (7.0 ",") ","
 (PPIQ08-PPIQ09 PPIQ09A PPIQ09B PPIQ11  PPIQ11A PPIQ11B PPIQ11C PPIQ11D 
  PPIQ12-PPIQ17 PPIQ17A PPIQ17B PPIQ17C PPIQ18-PPIQ25   PPIQ30-PPIQ34) (13.2 ",") ","
 (OPIQ08-OPIQ09 OPIQ09A OPIQ09B OPIQ11  OPIQ11A OPIQ11B OPIQ11C OPIQ11D 
  OPIQ12-OPIQ17 OPIQ17A OPIQ17B OPIQ17C OPIQ18-OPIQ25   OPIQ30-OPIQ34) (12.10 ",")  ","
 (EPIQ08-EPIQ09 EPIQ09A EPIQ09B EPIQ11  EPIQ11A EPIQ11B EPIQ11C EPIQ11D 
  EPIQ12-EPIQ17 EPIQ17A EPIQ17B EPIQ17C EPIQ18-EPIQ25 EPIQ30-EPIQ34) (12.10 ",")  ","
 (RPIQ08-RPIQ09 RPIQ09A RPIQ09B RPIQ11  RPIQ11A RPIQ11B RPIQ11C RPIQ11D 
  RPIQ12-RPIQ17 RPIQ17A RPIQ17B RPIQ17C RPIQ18-RPIQ25   RPIQ30-RPIQ34) (12.10 ",")  ","
 (LPIQ08-LPIQ09 LPIQ09A LPIQ09B LPIQ11  LPIQ11A LPIQ11B LPIQ11C LPIQ11D
  LPIQ12-LPIQ17 LPIQ17A LPIQ17B LPIQ17C LPIQ18-LPIQ25   LPIQ30-LPIQ34) (12.10 ",")  ","
 (UPIQ08-UPIQ09 UPIQ09A UPIQ09B UPIQ11  UPIQ11A UPIQ11B UPIQ11C UPIQ11D 
  UPIQ12-UPIQ17 UPIQ17A UPIQ17B UPIQ17C UPIQ18-UPIQ25   UPIQ30-UPIQ34) (12.10 ",")  ","
 (SPIQ08-SPIQ09 SPIQ09A SPIQ09B SPIQ11  SPIQ11A SPIQ11B SPIQ11C SPIQ11D 
  SPIQ12-SPIQ17 SPIQ17A SPIQ17B SPIQ17C SPIQ18-SPIQ25   SPIQ30-SPIQ34) (12.10 ",")  ","
 (XPIQ08-XPIQ09 XPIQ09A XPIQ09B XPIQ11  XPIQ11A XPIQ11B XPIQ11C XPIQ11D
  XPIQ12-XPIQ17 XPIQ17A XPIQ17B XPIQ17C XPIQ18-XPIQ25   XPIQ30-XPIQ34) (12.10 ",") 
 ;

 RUN;

 %END;

 %MEND TEXT;

 %TEXT;
